import React, { useState, useEffect, useCallback } from "react";
import ReactFlow, {
    addEdge,
    Controls,
    Background,
} from "reactflow";
import "reactflow/dist/style.css";
import "./FlowEditor.css"; 

const fetchNodes = async () => {
    const response = await fetch("/api/workflow");
    return response.json();
};

const saveWorkflow = async (workflow) => {
    await fetch("/api/workflow", {
        method: "POST",
        headers: { "Content-Type": "application/json" },
        body: JSON.stringify(workflow),
    });
};

export default function FlowEditor() {
    const [elements, setElements] = useState([]);

    useEffect(() => {
        fetchNodes().then((data) => setElements([...data.nodes, ...data.edges]));
    }, []);

    const onConnect = useCallback(
        (params) => {
            const newEdge = { id: `e${params.source}-${params.target}`, ...params };
            setElements((els) => [...els, newEdge]);
            saveWorkflow({ nodes: elements.filter(e => e.type), edges: [...elements.filter(e => !e.type), newEdge] });
        },
        [elements]
    );

    return (
        <div className="flow-editor-container">
            <ReactFlow elements={elements} onConnect={onConnect}>
                <Controls />
                <Background
                    variant="lines"
                    gap={100}
                    size={1}
                    color="rgba(255, 255, 255, 0.2)" // White grid with 20% opacity
                />
            </ReactFlow>
        </div>
    );
}
